@@ -1,6 +1,3 @@
-import gettext
-gettext.install('pynote')
-
-__version__ = '0.2.2'
+__version__ = '1.0.0'
 __license__ = 'MIT'
 __copyright__ = '(c) 2013-2014 Stefan Tatschner <stefan@sevenbyte.org>'
